import { ParamCalculability } from "../param/param-definition";
import { Structure, StructureFlowMode, StructureFlowRegime } from "../structure/structure";
import { Message, MessageCode } from "../util/message";
import { Result } from "../util/result";
import { StructureOrificeFreeParams } from "./structure_orifice_free_params";
import { LoiDebit } from "./structure_props";

/**
 * Equation classique orifice dénoyé
 */
export class StructureOrificeFree extends Structure {

    constructor(prms: StructureOrificeFreeParams, dbg: boolean = false) {
        super(prms, dbg);
        this._loiDebit = LoiDebit.OrificeFree;
        this._isZDVcalculable = false;
    }

    /**
     * paramètres castés au bon type
     */
    get prms(): StructureOrificeFreeParams {
        return this._prms as StructureOrificeFreeParams;
    }

    public Calc(sVarCalc: string, rInit?: number): Result {
        this.currentResult = super.Calc(sVarCalc, rInit);
        if (this._loiDebit === LoiDebit.OrificeFree && this.prms.Z2.v > this.prms.Zco.v) {
            this._result.resultElement.addMessage(new Message(
                MessageCode.WARNING_ORIFICE_FREE_DOWNSTREAM_ELEVATION_POSSIBLE_SUBMERSION,
                {
                    Z2: this.prms.Z2.v,
                    Zco: this.prms.Zco.v
                }
            ));
        }
        return this._result;
    }

    /**
     * Calcul du débit avec l'équation classique d'un orifice dénoyé
     */
    public CalcQ(): Result {
        const data = this.getResultData();

        const v = this.prms.CdO.v * this.prms.S.v * Structure.R2G * Math.sqrt(Math.max(0, this.prms.h1.v));

        return new Result(v, this, data);
    }

    protected getFlowRegime() {
        return StructureFlowRegime.FREE;
    }

    protected getFlowMode() {
        return StructureFlowMode.ORIFICE;
    }

    protected setParametersCalculability() {
        super.setParametersCalculability();
        this.prms.S.calculability = ParamCalculability.DICHO;
        this.prms.CdO.calculability = ParamCalculability.DICHO;
        this.prms.Zco.calculability = ParamCalculability.DICHO;
        this.prms.ZDV.visible = false;
    }
}
